##
##  tesseract.spec -- OpenPKG RPM Package Specification
##  Copyright (c) 2000-2024 OpenPKG Project <http://openpkg.org/>
##
##  Permission to use, copy, modify, and distribute this software for
##  any purpose with or without fee is hereby granted, provided that
##  the above copyright notice and this permission notice appear in all
##  copies.
##
##  THIS SOFTWARE IS PROVIDED ``AS IS'' AND ANY EXPRESSED OR IMPLIED
##  WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE IMPLIED WARRANTIES OF
##  MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE ARE DISCLAIMED.
##  IN NO EVENT SHALL THE AUTHORS AND COPYRIGHT HOLDERS AND THEIR
##  CONTRIBUTORS BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL,
##  SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT
##  LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF
##  USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND
##  ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY,
##  OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT
##  OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF
##  SUCH DAMAGE.
##

#   package version
%define       V_opkg  5.5.0
%define       V_dist  5.5.0

#   package information
Name:         tesseract
Summary:      Optical Character Recognition (OCR) Engine
URL:          https://github.com/tesseract-ocr/tesseract/
Vendor:       HP Laboratories Bristol, Ray Smith et al.
Packager:     OpenPKG Project
Distribution: OpenPKG Community
Class:        EVAL
Group:        Algorithm
License:      Apache
Version:      %{V_opkg}
Release:      20241112

#   list of sources
Source0:      https://github.com/tesseract-ocr/tesseract/archive/%{V_dist}.tar.gz

#   build information
BuildPreReq:  OpenPKG, openpkg >= 20160101, gcc, gcc::with_cxx = yes
PreReq:       OpenPKG, openpkg >= 20160101, tesseract-data
BuildPreReq:  leptonica, glib, freetype, pango, icu
PreReq:       leptonica, glib, freetype, pango, icu

%description
    This package contains an Optical Character Recognition (OCR) engine
    (libtesseract) and a command line program (tesseract).

%track
    prog tesseract = {
        version   = %{V_dist}
        url       = https://github.com/tesseract-ocr/tesseract/releases
        regex     = tree/(\d+\.\d+\.\d+)
    }

%prep
    %setup -q -n tesseract-%{V_dist}

%build
    sh autogen.sh
    CC="%{l_cc}" \
    CXX="%{l_cxx}" \
    CFLAGS="%{l_cflags -O} -pthread" \
    CXXFLAGS="%{l_cxxflags -O} -pthread" \
    CPPFLAGS="%{l_cppflags}" \
    LDFLAGS="%{l_ldflags}" \
    LIBLEPT_HEADERSDIR=%{l_prefix}/include/leptonica \
    LIBS="-lpng -lz -ljpeg -ltiff" \
    ./configure \
        --prefix=%{l_prefix} \
        --mandir=%{l_prefix}/man \
        --disable-shared
    %{l_make} %{l_mflags -O}

%install
    %{l_make} %{l_mflags} install AM_MAKEFLAGS="DESTDIR=$RPM_BUILD_ROOT"
    strip $RPM_BUILD_ROOT%{l_prefix}/bin/* >/dev/null 2>&1 || true
    %{l_rpmtool} files -v -ofiles -r$RPM_BUILD_ROOT %{l_files_std}

%files -f files

%clean

